//---------------------------------------------------------------------------
// jrdebug_output_formatters_plaintext.h
// derived methods for different outputs
//---------------------------------------------------------------------------

#include <string>


//---------------------------------------------------------------------------
// PlainText
// register the factory
JrDebugRegisterOutputFormatter(JrDebugRegisteredOutputFormatter_PlainText);
//---------------------------------------------------------------------------



//---------------------------------------------------------------------------
// constructor and destructor
JrDebugRegisteredOutputFormatter_PlainText::JrDebugRegisteredOutputFormatter_PlainText(bool isfactory)
	:JrDebugRegisteredOutputFormatter()
{
	// register if appropraite
	if (isfactory)
		{
		// create a NEW object for registering, dont try to attach this global one
		JrDebugSingletonInsurer dummy(false);
		JrDebug::RegisterFormatterFactory(MakeNew());
		return;
		}
}
//---------------------------------------------------------------------------


//---------------------------------------------------------------------------
// shutdown and startup
bool JrDebugRegisteredOutputFormatter_PlainText::Startup(const char *optionstring)
{
	if (strstr(optionstring,"noprefix")!=NULL)
		{
		flag_doshowtypeprefix=false;
		}
	else
		{
		flag_doshowtypeprefix=true;
		}

	if (strstr(optionstring,"notimestamp")!=NULL)
		{
		flag_doshowtimestamps=false;
		}
	else
		{
		flag_doshowtimestamps=true;
		}


/*
//old
	// process optionstring
	if (strcmp(optionstring,"")!=0)
		return false;
*/

	return true;
}

bool JrDebugRegisteredOutputFormatter_PlainText::Shutdown()
{
	// virtual shut down (any open files will be closed by caller when we return)
	return true;
}
//---------------------------------------------------------------------------






//---------------------------------------------------------------------------
// HandleDebugMessage should format the user's string and call DoOutput one or more times
// Note it will be invoked with any user % args already repalced
void JrDebugRegisteredOutputFormatter_PlainText::HandleDebugMessage(JrDebug *jrd, const char *str)
{
	// Format for plaintext, just send it directly but add newline

	jrd_stdstringT outstr;
	
	if (flag_doshowtimestamps)
		{
		outstr+=std::string(jrd->get_timestampstring().c_str())+" -> ";
		}


	if (flag_doshowtypeprefix)
		{
		outstr+=std::string(jrd->get_messagetypestring().c_str())+": ";
		}


	outstr+=std::string(str)+"\n";


    //
	DoOutput(outstr.c_str());
	// touch unused args to avoid compiler warnings
	JrdUnusedArg(jrd);
}
//---------------------------------------------------------------------------
